/*
    This include file allows you to use ANY public PETSc function
*/

#include <petscbag.h>
#include <petsctime.h>
#include <petscbt.h>
#include <petscctable.h>
#include <petscmatlab.h>
#include <petscdraw.h>

#include <petscsf.h>
#include <petscdmda.h>
#include <petscdmcomposite.h>
#include <petscdmpatch.h>
#include <petscdmplex.h>
#include <petscdmredundant.h>
#include <petscdmshell.h>
#include <petscdmsliced.h>
#include <petscdmswarm.h>
#include <petscdmstag.h>

#include <petscdt.h>
#include <petscds.h>

#include <petsccharacteristic.h>


#include <petscts.h>
#include <petsctao.h>
